@@ -449,7 +449,7 @@ typedef struct drm_buf_pub {
  */
 typedef struct drm_buf_map {
 	int	      count;	/**< Length of the buffer list */
-	void	      *virtual;	/**< Mmap'd area in user-virtual */
+	void	      *c_virtual;	/**< Mmap'd area in user-virtual */
 	drm_buf_pub_t *list;	/**< Buffer information */
 } drm_buf_map_t;
 
